@@ -7,8 +7,9 @@
 var animint = function (to_select, json_file) {
   var steps = [];
   var default_axis_px = 16;
-
-   function wait_until_then(timeout, condFun, readyFun) {
+  var grid_layout = false;
+  var grid_layout_table;
+  function wait_until_then(timeout, condFun, readyFun) {
     var args=arguments
     function checkFun() {
       if(condFun()) {
@@ -122,7 +123,7 @@ var animint = function (to_select, json_file) {
   // and then measure the element
   // Inspired from http://jsfiddle.net/uzddx/2/
   var measureText = function(pText, pFontSize, pAngle, pStyle) {
-    if (!pText || pText.length === 0) return {height: 0, width: 0};
+    if (pText === undefined || pText === null || pText.length === 0) return {height: 0, width: 0};
     if (pAngle === null || isNaN(pAngle)) pAngle = 0;
 
     var container = element.append('svg');
@@ -147,6 +148,12 @@ var animint = function (to_select, json_file) {
   dirs.pop(); //if a directory path exists, remove the JSON file from dirs
   var element = d3.select(to_select);
   this.element = element;
+  var tooltip = element.append("div")
+      .attr("class", "animint-tooltip")
+      .style("opacity", 0);
+  var hide_tooltip = function() {
+    tooltip.style("opacity", 0);
+  };
   var viz_id = element.attr("id");
   var plot_widget_table = element.append("table");
   var plot_td = plot_widget_table.append("tr").append("td");
@@ -243,11 +250,28 @@ var animint = function (to_select, json_file) {
     // Save this geom and load it!
     update_geom(g_name, null);
   };
-  var add_plot = function (p_name, p_info) {
-    // Each plot may have one or more legends. To make space for the
-    // legends, we put each plot in a table with one row and two
-    // columns: tdLeft and tdRight.
-    var plot_table = plot_td.append("table").style("display", "inline-block");
+  var grid_layout_tr = null; //static between add_plot calls.
+  var add_plot = function (p_name, p_info, grid_layout) {
+    var plot_table;
+    if(grid_layout) {
+      var grid_info = p_info.span || {};
+      if(grid_layout_tr === null) {
+        grid_layout_tr = grid_layout_table.append("tr");
+      }
+      var grid_layout_td = grid_layout_tr.append("td");
+      if(grid_info.rowspan > 0){
+        grid_layout_td.attr("rowspan", grid_info.rowspan);
+      }
+      if(grid_info.colspan > 0){
+        grid_layout_td.attr("colspan", grid_info.colspan);
+      }
+      plot_table = grid_layout_td.append("table")
+      if(grid_info.last_in_row){
+        grid_layout_tr = null;
+      }
+    }else{
+      plot_table = plot_td.append("table").style("display", "inline-block");
+    }
     var plot_tr = plot_table.append("tr");
     var tdLeft = plot_tr.append("td");
     var tdRight = plot_tr.append("td").attr("class", p_name+"_legend");
@@ -260,7 +284,7 @@ var animint = function (to_select, json_file) {
       .attr("id", p_info.plot_id)
       .attr("height", p_info.options.height)
       .attr("width", p_info.options.width);
-
+    
     // divvy up width/height based on the panel layout
     var nrows = Math.max.apply(null, p_info.layout.ROW);
     var ncols = Math.max.apply(null, p_info.layout.COL);
@@ -1076,6 +1100,15 @@ var animint = function (to_select, json_file) {
       });
     };
 
+    var fontsize = 12;
+    var get_fontsize;
+    if (aes.hasOwnProperty("size")){
+      get_fontsize = get_attr("size")
+    }else if(g_info.params.hasOwnProperty("size")){
+      get_fontsize = function(d) { return g_info.params.size; };
+    }else{
+      get_fontsize = function(d) { return fontsize; };
+    }
     var size = 2;
     var get_size;
     if(aes.hasOwnProperty("size")){
@@ -1140,15 +1173,36 @@ var animint = function (to_select, json_file) {
       };
     }
     var get_colour_off_default = get_colour;
-
-    var fill = "black", fill_off = "black";
+    if (g_info.geom == "label_aligned") {
+      var fill = "white", fill_off = "white";
+    }else{
+      var fill = "black", fill_off = "black";
+    }
     var get_fill = function (d) {
       return fill;
     };
     var get_fill_off = function (d) {
       return fill_off;
     };
-    
+
+    var get_hjust;
+    var default_hjust = 0.5; // default center
+    if(aes.hasOwnProperty("hjust")){
+      get_hjust = get_attr("hjust");
+    }else if(g_info.params.hasOwnProperty("hjust")){
+      get_hjust = function(d){ return g_info.params.hjust; };
+    }else{
+      get_hjust = function(d){ return default_hjust; };
+    }
+    var get_vjust;
+    var default_vjust = 0.5; // default center
+    if(aes.hasOwnProperty("vjust")){
+      get_vjust = get_attr("vjust");
+    }else if(g_info.params.hasOwnProperty("vjust")){
+      get_vjust = function(d){ return g_info.params.vjust; };
+    }else{
+      get_vjust = function(d){ return default_vjust; };
+    }
     var angle = 0;
     var get_angle;
     if(aes.hasOwnProperty("angle")){
@@ -1325,22 +1379,57 @@ var animint = function (to_select, json_file) {
       }
       data_to_bind = data;
       if (g_info.geom == "segment") {
-	g_info.style_list = line_style_list;
-	eActions = function (e) {
-          e.attr("x1", function (d) {
-            return scales.x(d["x"]);
-          })
-            .attr("x2", function (d) {
-              return scales.x(d["xend"]);
-            })
-            .attr("y1", function (d) {
-              return scales.y(d["y"]);
-            })
-            .attr("y2", function (d) {
-              return scales.y(d["yend"]);
-            })
-	};
-	eAppend = "line";
+  g_info.style_list = line_style_list;
+  // helper: get slope and intercept for datum
+  function getLineParams(d) {
+    var slope = d.slope !== undefined ? +d.slope :
+      (g_info.abline_params && g_info.abline_params.slopes) ? g_info.abline_params.slopes[d.i] : 1;
+    var intercept = d.intercept !== undefined ? +d.intercept :
+      (g_info.abline_params && g_info.abline_params.intercepts) ? g_info.abline_params.intercepts[d.i] : 0;
+    return { slope, intercept };
+  }
+  // helper: compute clipped coordinate for one endpoint
+  function computeEndpoint(x, slope, intercept, xDomain, yDomain) {
+    var y = slope * x + intercept;
+    if (y < yDomain[0]) x = (yDomain[0] - intercept) / slope;
+    if (y > yDomain[1]) x = (yDomain[1] - intercept) / slope;
+    return { x, y };
+  }
+  // helper: compute abline endpoints
+  function getAblineCoords(d, scales) {
+    var { slope, intercept } = getLineParams(d);
+    var xDomain = scales.x.domain();
+    var yDomain = scales.y.domain();
+    function get_ab_y(x) {
+      return Math.max(yDomain[0], Math.min(yDomain[1], slope * x + intercept));
+    }
+    // Compute both endpoints
+    var start = computeEndpoint(xDomain[0], slope, intercept, xDomain, yDomain);
+    var end = computeEndpoint(xDomain[1], slope, intercept, xDomain, yDomain);
+    return {
+      x1: scales.x(start.x),
+      y1: scales.y(get_ab_y(xDomain[0])),
+      x2: scales.x(end.x),
+      y2: scales.y(get_ab_y(xDomain[1]))
+    };
+  }
+  if (g_info.is_abline) {
+    eActions = function(e) {
+      e.attr("x1", d => getAblineCoords(d, scales).x1)
+       .attr("y1", d => getAblineCoords(d, scales).y1)
+       .attr("x2", d => getAblineCoords(d, scales).x2)
+       .attr("y2", d => getAblineCoords(d, scales).y2);
+    };
+  } else {
+    // Regular segment case
+    eActions = function(e) {
+      e.attr("x1", toXY("x", "x"))
+        .attr("y1", toXY("y", "y"))
+        .attr("x2", toXY("x", "xend"))
+        .attr("y2", toXY("y", "yend"));
+    };
+  }
+  eAppend = "line";
       }
       if (g_info.geom == "linerange") {
 	g_info.style_list = line_style_list;
@@ -1429,6 +1518,118 @@ var animint = function (to_select, json_file) {
 	};
 	eAppend = "circle";
       }
+      // function to calculate the size of boxes in geom_label_aligned according to the inside text
+      var calcLabelBox = function(d) {
+        var textStyle = [
+            "font-family:" + (d.family || "sans-serif"),
+            "font-weight:" + (d.fontface == 2 ? "bold" : "normal"),
+            "font-style:" + (d.fontface == 3 ? "italic" : "normal")
+        ].join(";");
+        // Use d.size for font size (always current value)
+        var fontsize = d.size;
+        var textSize = measureText(d.label, fontsize, d.angle, textStyle);
+        d.boxWidth = textSize.width;
+        d.boxHeight = textSize.height;
+        d.scaledX = scales.x(d.x);
+        d.scaledY = scales.y(d.y);
+      }
+      if (g_info.geom == "label_aligned") {
+          // Get parameters
+          var alignment = g_info.params.alignment || "vertical";
+          var min_distance = g_info.params.min_distance || 0.1;
+          var background_rect = g_info.params.background_rect !== false; // Default true
+          // Set d.size and d.originalFontsize for each datum
+          data.forEach(function(d) {
+              if (typeof d.originalFontsize === "undefined") {
+                  d.size = get_fontsize(d);
+                  d.originalFontsize = d.size;
+              }
+              // Always reset to original before shrinking
+              d.size = d.originalFontsize;
+              calcLabelBox(d);
+          });
+          var plot_limits;
+          if (alignment === "vertical") {
+            var yRange = scales.y.range();
+            plot_limits = [Math.min.apply(null, yRange), Math.max.apply(null, yRange)];
+          } else {
+            var xRange = scales.x.range();
+            plot_limits = [Math.min.apply(null, xRange), Math.max.apply(null, xRange)];
+          }
+          // using quadprog.js for optimizing positions of colliding boxes
+          optimizeAlignedLabels(data, alignment, min_distance, plot_limits, function(d){return d.size;}, calcLabelBox);
+
+          eAppend = "g";
+          eActions = function(groups) {
+            // Handle transitions seperately due to unique structure of geom_label_aligned
+            var transitionDuration = 0;
+            if (Selectors.hasOwnProperty(selector_name)) {
+              transitionDuration = +Selectors[selector_name].duration || 0;
+            }
+            groups.each(function(d) {
+              var group = d3.select(this);
+              // Select existing elements (if any)
+              var rect = group.select("rect");
+              var text = group.select("text");
+              var rectIsNew = false, textIsNew = false;
+              // If elements don't exist, create them
+              if (rect.empty()) {rect = group.append("rect"); rectIsNew = true;}
+              if (text.empty()) {text = group.append("text"); textIsNew = true;}
+              // Apply transitions to both elements
+              if (!rectIsNew && transitionDuration > 0) {
+                rect = rect.transition().duration(transitionDuration);
+              }
+              if (!textIsNew && transitionDuration > 0) {
+                text = text.transition().duration(transitionDuration);
+              }
+              if (background_rect) {
+                rect
+                  .attr("x", function(d) { 
+                    if (alignment == "vertical") {
+                      return d.scaledX - d.boxWidth * get_hjust(d);
+                    } else {
+                      return d.optimizedPos - d.boxWidth / 2;
+                    }
+                  })
+                  .attr("y", function(d) {
+                    if (alignment == "vertical") {
+                      return d.optimizedPos - d.boxHeight / 2;
+                    } else {
+                      return d.scaledY - d.boxHeight * (1 - get_vjust(d));
+                    }
+                  })
+                  .attr("width", function(d) { return d.boxWidth; })
+                  .attr("height", function(d) { return d.boxHeight; })
+                  .style("opacity", get_alpha)
+                  .style("stroke", get_colour)
+                  .style("fill", get_fill)
+                  .attr("rx", g_info.params.label_r || 0)
+                  .attr("ry", g_info.params.label_r || 0);
+              }
+              text
+                .attr("x", function(d) {
+                  if (alignment == "vertical") {
+                    return d.scaledX - d.boxWidth * get_hjust(d) + d.boxWidth / 2;
+                  } else {
+                    return d.optimizedPos;
+                  }
+                })
+                .attr("y", function(d) {
+                  if (alignment == "vertical") {
+                    return d.optimizedPos;
+                  } else {
+                    return d.scaledY - d.boxHeight * (1 - get_vjust(d)) + d.boxHeight / 2 ;
+                  }
+                })
+                .attr("dominant-baseline", "middle")
+                .attr("font-size", function(d) { return d.size + "px"; })
+                .style("text-anchor", "middle")
+                .style("fill", get_colour)
+                .text(function(d) { return d.label; });
+            });
+          };
+        }
+
       var rect_geoms = ["tallrect","widerect","rect"];
       if(rect_geoms.includes(g_info.geom)){
 	eAppend = "rect";
@@ -1517,6 +1718,7 @@ var animint = function (to_select, json_file) {
       size = g_info.params.size;
     }
     var styleActions = function(e){
+      if (g_info.geom == "label_aligned") return;  // Do NOT call styleActions(e) for geom_label_aligned
       g_info.style_list.forEach(function(s){
 	e.style(s, function(d) {
 	  var style_on_fun = style_on_funs[s];
@@ -1540,15 +1742,18 @@ var animint = function (to_select, json_file) {
     var select_style_default = ["opacity","stroke","fill"];
     g_info.select_style = select_style_default.filter(
       X => g_info.style_list.includes(X));
+    var styles_to_apply = (g_info.geom === "label_aligned") ? ["opacity"] : g_info.select_style;
+    // (Only apply opacity to geom_label_aligned 
+    // due to its structure difference -- to avoid double styling in both <g> and <text> inside <g>)
     var over_fun = function(e){
-      g_info.select_style.forEach(function(s){
+      styles_to_apply.forEach(function(s){
         e.style(s, function (d) {
           return style_on_funs[s](d);
         });
       });
     };
     var out_fun = function(e){
-      g_info.select_style.forEach(function(s){
+      styles_to_apply.forEach(function(s){
         e.style(s, function (d) {
           var select_on = style_on_funs[s](d);
           var select_off = style_off_funs[s](d);
@@ -1610,7 +1815,23 @@ var animint = function (to_select, json_file) {
     };
     doActions(enter);  // DO NOT DELETE!
     var has_tooltip = g_info.aes.hasOwnProperty("tooltip");
+    function positionTooltip(tooltip, content) {
+      var mouseX = 0, mouseY = 0;
+      if (d3.event) {
+        mouseX = d3.event.pageX;
+        mouseY = d3.event.pageY;
+      }
+      var safeHtml = String(content).replace(/\n/g, '<br/>');
+      tooltip
+        .html(safeHtml)
+        .style("left", (mouseX + TOOLTIP_HORIZONTAL_OFFSET) + "px")
+        .style("top", (mouseY - TOOLTIP_VERTICAL_OFFSET) + "px")
+        .style("opacity", 0.7);
+    }
     if(has_clickSelects || has_tooltip || has_clickSelects_variable){
+      // Tooltip positioning constants
+      var TOOLTIP_HORIZONTAL_OFFSET = 10; // pixels right of mouse pointer
+      var TOOLTIP_VERTICAL_OFFSET = 28;   // pixels above mouse pointer
       var text_fun;
       if(has_tooltip){
         text_fun = function(d){
@@ -1626,11 +1847,17 @@ var animint = function (to_select, json_file) {
 	  return d["clickSelects.variable"] + " " + d["clickSelects.value"];
 	};
       }
-      // if elements have an existing title, remove it.
-      elements.selectAll("title").remove();
-      elements.append("svg:title")
-        .text(get_fun(text_fun))
-      ;
+      // Add tooltip handlers
+      elements
+        .on("mouseover.tooltip", function(d) {
+          if (!d || typeof text_fun !== 'function') return;
+          var content = text_fun(d);
+          positionTooltip(tooltip, content);
+        })
+        .on("mouseout.tooltip", hide_tooltip)
+        .on("mousemove.tooltip", function() {
+          positionTooltip(tooltip, tooltip.html());
+        });
     }
     if(Selectors.hasOwnProperty(selector_name)){
       var milliseconds = Selectors[selector_name].duration;
@@ -1685,6 +1912,15 @@ var animint = function (to_select, json_file) {
       }
       return selected_values;
   };
+
+  // DEAD CODE FOR COVERAGE TESTING
+    function deadCodeForCoverage() {
+      // This function is never called and should show as uncovered in coverage reports.
+      var unused = 42;
+      if (unused === 43) {
+        console.log("This should never be printed.");
+      }
+    }
   
   // update scales for the plots that have update_axes option in
   // theme_animint
@@ -1843,6 +2079,7 @@ var animint = function (to_select, json_file) {
 	s_info.selected.push(value);
       }else{
 	// found, remove from selection.
+	hide_tooltip()
 	s_info.selected.splice(i_value, 1);
       }
     }
@@ -2047,9 +2284,20 @@ var animint = function (to_select, json_file) {
       // global d3.select here.
       d3.select("title").text(response.title);
     }
+    // checking for layout structure
+    for(var p_name in response.plots) {
+      let attributes = response.plots[p_name].span;
+        if(attributes.rowspan > 0 || attributes.colspan > 0 || attributes.last_in_row) {
+          grid_layout = true;
+          break;
+        }
+    }
+    if(grid_layout){
+      grid_layout_table = plot_td.append("table")
+    }
     // Add plots.
     for (var p_name in response.plots) {
-      add_plot(p_name, response.plots[p_name]);
+      add_plot(p_name, response.plots[p_name], grid_layout);
       add_legend(p_name, response.plots[p_name]);
       // Append style sheet to document head.
       css.appendChild(document.createTextNode(styles.join(" ")));
@@ -2531,4 +2779,3 @@ var animint = function (to_select, json_file) {
     }//if(window.location.hash)
   });
 };
-
